Function Send-MobilePushNotification
{
<# 
 .Synopsis
  Send Push notifications to mobile devices

 .Description
  Send Push notifications to mobile devices via Prawl (iOS), NotifyMyAndroid (Android) and NotifyMyWindowsPhone(Windows Phone).

 .Parameter -os
  Operating System of the mobile device. Valid value can be either "iOS", "Android" or "WindowsPhone".

 .Parameter -apikey
  the apikey obtained from one of these systems associated to the mobile device

 .Parameter -Subject
  Subject text for the notification message.

 .Parameter -Priority
  priorty of the notification message. valid value: '-2','-1','0','1','2'. if not specified, the priority defaults to 0.

 .Parameter -Application
  Name of the application that's sending the notification message.

 .Parameter -Body
  Notification message body text. The body text will be truncated to the first 10,000 characters.


 .Example
  # Send a push notification to an Android device:
  Send-MobilePushNotification -OS 'Android' -apikey '1234567890987654321' -Subject 'Hello world' -Application 'SMA' -Body 'this is a system generated message'
#>

    Param(

        [Parameter (Mandatory=$true)][string][ValidateSet('Android','Windows','iOS')]$os,
        [Parameter (Mandatory=$true)][string]$apikey,
        [Parameter (Mandatory=$true)][string]$Subject,
        [Parameter (Mandatory=$false)][String][ValidateSet('-2','-1','0','1','2')]$Priority = '0',
        [Parameter (Mandatory=$true)][string]$Application,
        [Parameter (Mandatory=$true)][string]$Body
    ) 

    #description maximum length is 10000, truncate it if it's over
    If ($Body.length -gt 10000)
    {
	    $Body = $Body.substring(0,10000)
    }

    # Specifies the responsetype you want. You can currently choose between JSON or XML (default)
    $type = 'json'
    $os = $os.tolower()
    Switch ($os.ToLower())
    {
	    'android' {$uri = "http://notifymyandroid.com/publicapi/notify?event=$Subject&priority=$priority&application=$Application&description=$Body&apikey=$apikey&type=$type"}
	    'windows' {$uri = "http://notifymywindowsphone.com/publicapi/notify?event=$Subject&priority=$priority&application=$Application&description=$Body&apikey=$apikey&type=$type"}
	    'ios' {$uri = "http://api.prowlapp.com/publicapi/add?event=$Subject&priority=$priority&application=$Application&description=$Body&apikey=$apikey&type=$type"}
    }

    #Invoke-WebRequest -Uri $uri
    $response = [System.Net.WebRequest]::Create($uri)
    $response.GetResponse()
    Write-Output $response
}